@@ -1,10 +1,10 @@
 import decimal
 import unittest
 from ptah import form
+from ptah.form import iso8601
+from ptah.testing import PtahTestCase
 from webob.multidict import MultiDict
 
-from base import Base
-
 
 class DummyRequest(object):
     def __init__(self):
@@ -16,7 +16,7 @@ def invalid_exc(func, *arg, **kw):
     from ptah.form import Invalid
     try:
         func(*arg, **kw)
-    except Invalid, e:
+    except Invalid as e:
         return e
     else:
         raise AssertionError('Invalid not raised') # pragma: no cover
@@ -26,7 +26,7 @@ def strip(str):
     return ' '.join(s.strip() for s in str.split())
 
 
-class TestInputField(Base):
+class TestInputField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         from ptah.form.fields import InputField
@@ -36,7 +36,7 @@ class TestInputField(Base):
         request = DummyRequest()
 
         field = self._makeOne('test')
-        field = field.bind('', u'content', {})
+        field = field.bind('', 'content', {})
         field.update(request)
 
         self.assertEqual(field.klass, None)
@@ -47,7 +47,7 @@ class TestInputField(Base):
         self.assertEqual(field.klass, 'disabled')
 
 
-class TestTextField(Base):
+class TestTextField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.TextField(name, **kw)
@@ -56,11 +56,11 @@ class TestTextField(Base):
         request = DummyRequest()
 
         field = self._makeOne('test')
-        field = field.bind('', u'content', {})
+        field = field.bind('', 'content', {})
         field.update(request)
 
-        self.assertEqual(field.serialize(u'value'), u'value')
-        self.assertEqual(field.deserialize(u'value'), u'value')
+        self.assertEqual(field.serialize('value'), 'value')
+        self.assertEqual(field.deserialize('value'), 'value')
 
         self.assertEqual(strip(field.render(request)),
                          '<input type="text" name="test" title="Test" value="content" id="test" class="text-widget" />')
@@ -71,7 +71,7 @@ class TestTextField(Base):
 
 
         field = self._makeOne('test')
-        field = field.bind('', u'content', {'test': 'form'})
+        field = field.bind('', 'content', {'test': 'form'})
         field.update(request)
 
         self.assertEqual(strip(field.render(request)),
@@ -82,7 +82,7 @@ class TestTextField(Base):
                          '<span class="uneditable-input" id="test" title="Test"> form </span>')
 
 
-class TestIntegerField(Base):
+class TestIntegerField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.IntegerField(name, **kw)
@@ -96,17 +96,18 @@ class TestIntegerField(Base):
 
         self.assertIs(field.serialize(form.null), form.null)
         self.assertEqual(field.serialize(10), '10')
-        self.assertRaises(form.Invalid, field.serialize, u'value')
+        self.assertRaises(form.Invalid, field.serialize, 'value')
 
         self.assertIs(field.deserialize(''), form.null)
         self.assertEqual(field.deserialize('10'), 10)
-        self.assertRaises(form.Invalid, field.deserialize, u'value')
+        self.assertRaises(form.Invalid, field.deserialize, 'value')
 
         self.assertEqual(
             strip(field.render(request)),
             '<input type="text" name="test" title="Test" value="10" id="test" class="int-widget" />')
 
-class TestFloatField(Base):
+
+class TestFloatField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.FloatField(name, **kw)
@@ -120,18 +121,18 @@ class TestFloatField(Base):
 
         self.assertIs(field.serialize(form.null), form.null)
         self.assertEqual(field.serialize(10.34), '10.34')
-        self.assertRaises(form.Invalid, field.serialize, u'value')
+        self.assertRaises(form.Invalid, field.serialize, 'value')
 
         self.assertIs(field.deserialize(''), form.null)
         self.assertEqual(field.deserialize('10.34'), 10.34)
-        self.assertRaises(form.Invalid, field.deserialize, u'value')
+        self.assertRaises(form.Invalid, field.deserialize, 'value')
 
         self.assertEqual(
             strip(field.render(request)),
             '<input type="text" name="test" title="Test" value="10.34" id="test" class="float-widget" />')
 
 
-class TestDeciamlField(Base):
+class TestDeciamlField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.DecimalField(name, **kw)
@@ -145,18 +146,18 @@ class TestDeciamlField(Base):
 
         self.assertIs(field.serialize(form.null), form.null)
         self.assertEqual(field.serialize(decimal.Decimal('10.34')), '10.34')
-        self.assertRaises(form.Invalid, field.serialize, u'value')
+        self.assertRaises(form.Invalid, field.serialize, 'value')
 
         self.assertIs(field.deserialize(''), form.null)
         self.assertEqual(field.deserialize('10.34'), decimal.Decimal('10.34'))
-        self.assertRaises(form.Invalid, field.deserialize, u'value')
+        self.assertRaises(form.Invalid, field.deserialize, 'value')
 
         self.assertEqual(
             strip(field.render(request)),
             '<input type="text" name="test" title="Test" value="10.34" id="test" class="decimal-widget" />')
 
 
-class TestLinesField(Base):
+class TestLinesField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.LinesField(name, **kw)
@@ -181,7 +182,7 @@ class TestLinesField(Base):
             '<textarea rows="5" name="test" title="Test" cols="40" id="test" class="textlines-widget">1 2 3</textarea>')
 
 
-class TestVocabularyField(Base):
+class TestVocabularyField(PtahTestCase):
 
     def test_vocabulary_field(self):
         voc = form.SimpleVocabulary.from_items(
@@ -252,7 +253,7 @@ class TestVocabularyField(Base):
                            'value': 'three'}])
 
 
-class TestBaseChoiceField(Base):
+class TestBaseChoiceField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.BaseChoiceField(name, **kw)
@@ -288,7 +289,7 @@ class TestBaseChoiceField(Base):
         self.assertRaises(form.Invalid, field.deserialize, ['one','five'])
 
 
-class TestBaseMultiChoiceField(Base):
+class TestBaseMultiChoiceField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.BaseMultiChoiceField(name, **kw)
@@ -332,7 +333,7 @@ class TestBaseMultiChoiceField(Base):
         self.assertEqual(field.extract(), ['one'])
 
 
-class TestChoiceField(Base):
+class TestChoiceField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.ChoiceField(name, **kw)
@@ -370,9 +371,9 @@ class TestChoiceField(Base):
 
         self.assertEqual(field.items,
                          [{'checked': False,
-                           'description': u'',
+                           'description': '',
                            'id': 'test-novalue',
-                           'label': u'select a value ...',
+                           'label': 'select a value ...',
                            'name': 'test',
                            'value': '--NOVALUE--'},
                           {'checked': True,
@@ -389,7 +390,7 @@ class TestChoiceField(Base):
                            'value': 'two'}])
 
 
-class TestMultiChoiceField(Base):
+class TestMultiChoiceField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         return form.MultiChoiceField(name, **kw)
@@ -422,13 +423,11 @@ class TestDateTime(unittest.TestCase):
         return datetime.date.today()
 
     def test_ctor_default_tzinfo_None(self):
-        import iso8601
         typ = self._makeOne()
-        self.assertEqual(typ.default_tzinfo.__class__, iso8601.iso8601.Utc)
+        self.assertEqual(typ.default_tzinfo.__class__, iso8601.Utc)
 
     def test_ctor_default_tzinfo_non_None(self):
-        import iso8601
-        tzinfo = iso8601.iso8601.FixedOffset(1, 0, 'myname')
+        tzinfo = iso8601.FixedOffset(1, 0, 'myname')
         typ = self._makeOne(default_tzinfo=tzinfo)
         self.assertEqual(typ.default_tzinfo, tzinfo)
 
@@ -466,10 +465,9 @@ class TestDateTime(unittest.TestCase):
         self.assertEqual(result, dt.isoformat())
 
     def test_serialize_with_tzware_datetime(self):
-        import iso8601
         typ = self._makeOne()
         dt = self._dt()
-        tzinfo = iso8601.iso8601.FixedOffset(1, 0, 'myname')
+        tzinfo = iso8601.FixedOffset(1, 0, 'myname')
         dt = dt.replace(tzinfo=tzinfo)
         result = typ.serialize(dt)
         expected = dt.isoformat()
@@ -477,13 +475,12 @@ class TestDateTime(unittest.TestCase):
 
     def test_deserialize_date(self):
         import datetime
-        import iso8601
         date = self._today()
         typ = self._makeOne()
         formatted = date.isoformat()
         result = typ.deserialize(formatted)
         expected = datetime.datetime.combine(result, datetime.time())
-        tzinfo = iso8601.iso8601.Utc()
+        tzinfo = iso8601.Utc()
         expected = expected.replace(tzinfo=tzinfo)
         self.assertEqual(result.isoformat(), expected.isoformat())
 
@@ -503,18 +500,16 @@ class TestDateTime(unittest.TestCase):
         self.assertEqual(result, form.null)
 
     def test_deserialize_success(self):
-        import iso8601
         typ = self._makeOne()
         dt = self._dt()
-        tzinfo = iso8601.iso8601.FixedOffset(1, 0, 'myname')
+        tzinfo = iso8601.FixedOffset(1, 0, 'myname')
         dt = dt.replace(tzinfo=tzinfo)
         iso = dt.isoformat()
         result = typ.deserialize(iso)
         self.assertEqual(result.isoformat(), iso)
 
     def test_deserialize_naive_with_default_tzinfo(self):
-        import iso8601
-        tzinfo = iso8601.iso8601.FixedOffset(1, 0, 'myname')
+        tzinfo = iso8601.FixedOffset(1, 0, 'myname')
         typ = self._makeOne(default_tzinfo=tzinfo)
         dt = self._dt()
         dt_with_tz = dt.replace(tzinfo=tzinfo)
@@ -602,7 +597,7 @@ class TestDate(unittest.TestCase):
         self.assertEqual(result.isoformat(), dt.date().isoformat())
 
 
-class TestFileField(Base):
+class TestFileField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         from ptah.form.fields import FileField
@@ -612,7 +607,7 @@ class TestFileField(Base):
         request = DummyRequest()
 
         field = self._makeOne('test')
-        field = field.bind('', u'content', {})
+        field = field.bind('', 'content', {})
         field.update(request)
 
         self.assertIs(field.extract(), form.null)
@@ -627,7 +622,7 @@ class TestFileField(Base):
 
         fs = FileStorage(object(), 'test.jpg', 'image/jpeg', 1024)
 
-        field = field.bind('', u'content', {'test': fs})
+        field = field.bind('', 'content', {'test': fs})
         field.update(request)
 
         res = field.extract()
@@ -635,7 +630,7 @@ class TestFileField(Base):
         self.assertEqual(res['filename'], 'test.jpg')
 
 
-class TestJSDateTimeField(Base):
+class TestJSDateTimeField(PtahTestCase):
 
     def _makeOne(self, name, **kw):
         from ptah.form.jsfields import JSDateTimeField
@@ -644,14 +639,14 @@ class TestJSDateTimeField(Base):
     def test_fields_jsdatetime_update(self):
         from datetime import datetime
 
-        request = DummyRequest()
+        request = self.request
         field = self._makeOne('test')
 
         f = field.bind('', form.null, {})
         f.update(request)
 
-        self.assertEqual(f.date_part, u'')
-        self.assertEqual(f.time_part, u'')
+        self.assertEqual(f.date_part, '')
+        self.assertEqual(f.time_part, '')
 
         dt = datetime(2011, 1, 1, 10, 10)
 
@@ -664,7 +659,7 @@ class TestJSDateTimeField(Base):
     def test_fields_jsdatetime_extract(self):
         from datetime import datetime
 
-        request = DummyRequest()
+        request = self.request
         field = self._makeOne('test')
 
         f = field.bind('', form.null, {})
@@ -699,7 +694,7 @@ class TestJSDateTimeField(Base):
         self.assertEqual(f.extract(), '2011-12-01T10:10:00')
 
 
-class TestJSDateField(Base):
+class TestJSDateField(PtahTestCase):
 
     def _makeOne(self, **kw):
         from ptah.form.jsfields import JSDateField
