@@ -1,19 +1,20 @@
 import ptah
+from ptah.testing import PtahTestCase
 from pyramid.testing import DummyRequest
-
-from base import Base
+from pyramid.view import render_view_to_response
 
 
-class TestRestInspectorModule(Base):
+class TestRestInspectorModule(PtahTestCase):
 
     def test_rest_module(self):
         from ptah.manage.rest import RestModule
-        from ptah.manage.manage import CONFIG, PtahManageRoute
+        from ptah.manage.manage import PtahManageRoute
 
         request = DummyRequest()
 
-        ptah.authService.set_userid('test')
-        CONFIG['managers'] = ('*',)
+        ptah.auth_service.set_userid('test')
+        cfg = ptah.get_settings(ptah.CFG_ID_PTAH, self.registry)
+        cfg['managers'] = ('*',)
         mr = PtahManageRoute(request)
         mod = mr['rest']
 
@@ -26,13 +27,11 @@ class TestRestInspectorModule(Base):
 
         mod = RestModule(None, request)
 
-        res = RestModuleView.__renderer__(mod, request)
+        res = render_view_to_response(mod, request, '', False)
         self.assertEqual(res.status, '200 OK')
 
         view = RestModuleView(mod, request)
         view.update()
 
         self.assertEqual(
-            view.appurl, request.application_url)
-        self.assertEqual(
-            view.url, '%s/__rest__/cms/' % request.application_url)
+            view.url, '{0}/__rest__/cms/'.format(request.application_url))
