@@ -1,20 +1,22 @@
-""" role """
 from zope import interface
-from ptah import config
 from pyramid.security import Allow, Deny, ALL_PERMISSIONS, DENY_ALL
 from pyramid.security import NO_PERMISSION_REQUIRED
 from pyramid.httpexceptions import HTTPForbidden
+from pyramid.exceptions import ConfigurationConflictError
 
-from base import Base
+import ptah
+from ptah.testing import PtahTestCase
 
 
-class TestPermission(Base):
+class TestPermission(PtahTestCase):
+
+    _init_ptah = False
 
     def test_permission_register(self):
         import ptah
 
         perm = ptah.Permission('perm', 'Permission', 'Test permission')
-        self._init_ptah()
+        self.init_ptah()
 
         self.assertTrue(perm == 'perm')
         self.assertTrue(perm.title == 'Permission')
@@ -27,22 +29,20 @@ class TestPermission(Base):
         ptah.Permission('perm', 'Permission1')
         ptah.Permission('perm', 'Permission2')
 
-        self.assertRaises(config.ConflictError, self._init_ptah)
+        self.assertRaises(ConfigurationConflictError, self.init_ptah)
 
 
-class TestACL(Base):
+class TestACL(PtahTestCase):
 
-    def tearDown(self):
-        config.cleanup_system(self.__class__.__module__)
-        super(TestACL, self).tearDown()
+    _init_ptah = False
 
     def test_acl_register(self):
         import ptah
 
         pmap = ptah.ACL('map', 'ACL', 'Map')
-        self._init_ptah()
+        self.init_ptah()
 
-        self.assertTrue(pmap.name == 'map')
+        self.assertTrue(pmap.id == 'map')
         self.assertTrue(pmap.title == 'ACL')
         self.assertTrue(pmap.description == 'Map')
         self.assertTrue(ptah.get_acls()['map'] is pmap)
@@ -53,7 +53,7 @@ class TestACL(Base):
         ptah.ACL('map', 'acl1')
         ptah.ACL('map', 'acl2')
 
-        self.assertRaises(config.ConflictError, self._init_ptah)
+        self.assertRaises(ConfigurationConflictError, self.init_ptah)
 
     def test_acl_allow(self):
         import ptah
@@ -230,11 +230,9 @@ class TestACL(Base):
         self.assertEqual(pmap[1][2], set(('perm1','perm2')))
 
 
-class TestACLsProps(Base):
+class TestACLsProps(PtahTestCase):
 
-    def tearDown(self):
-        config.cleanup_system(self.__class__.__module__)
-        super(TestACLsProps, self).tearDown()
+    _init_ptah = False
 
     def test_acls(self):
         import ptah
@@ -245,7 +243,7 @@ class TestACLsProps(Base):
         acl2 = ptah.ACL('acl2', 'acl2')
         acl2.deny('role1', 'perm1', 'perm2')
 
-        self._init_ptah()
+        self.init_ptah()
 
         class Content(object):
             __acl__ = ptah.ACLsProperty()
@@ -272,11 +270,9 @@ class TestACLsProps(Base):
                           ['Allow', 'role1', set(['perm2', 'perm1'])]])
 
 
-class TestRole(Base):
+class TestRole(PtahTestCase):
 
-    def tearDown(self):
-        config.cleanup_system(self.__class__.__module__)
-        super(TestRole, self).tearDown()
+    _init_ptah = False
 
     def test_role_register(self):
         import ptah
@@ -296,13 +292,13 @@ class TestRole(Base):
         ptah.Role('myrole', 'MyRole1')
         ptah.Role('myrole', 'MyRole2')
 
-        self.assertRaises(config.ConflictError, self._init_ptah)
+        self.assertRaises(ConfigurationConflictError, self.init_ptah)
 
     def test_role_roles(self):
         import ptah
 
         role = ptah.Role('myrole', 'MyRole')
-        self._init_ptah()
+        self.init_ptah()
 
         self.assertTrue('myrole' in ptah.get_roles())
         self.assertTrue(ptah.get_roles()['myrole'] is role)
@@ -360,15 +356,12 @@ class TestRole(Base):
         self.assertEqual(len(DEFAULT_ACL), 0)
 
 
-class TestDefaultRoles(Base):
+class TestDefaultRoles(PtahTestCase):
 
     def test_role_defaults(self):
         import ptah
-        self._init_ptah()
 
-        roles = list(ptah.get_roles().keys())
-        roles.sort()
-        roles = roles[:3]
+        roles = sorted(list(ptah.get_roles().keys()))[:3]
 
         self.assertTrue(['Authenticated', 'Everyone', 'Owner'] == roles)
         self.assertTrue(ptah.get_roles()['Everyone'].id == 'system.Everyone')
@@ -388,7 +381,7 @@ class Content(object):
             interface.directlyProvides(self, iface)
 
 
-class TestLocalRoles(Base):
+class TestLocalRoles(PtahTestCase):
 
     def test_local_role_simple(self):
         from ptah import security
@@ -426,8 +419,7 @@ class TestLocalRoles(Base):
         parent.__local_roles__['userid'] = ('role:test',)
         content.__local_roles__['userid'] = ('role:test2',)
 
-        lr = security.get_local_roles('userid', context=content)
-        lr.sort()
+        lr = sorted(security.get_local_roles('userid', context=content))
 
         self.assertTrue(lr == ['role:test', 'role:test2'])
 
@@ -477,7 +469,7 @@ class Content2(object):
             interface.directlyProvides(self, iface)
 
 
-class TestOwnerLocalRoles(Base):
+class TestOwnerLocalRoles(PtahTestCase):
 
     def test_owner_role_simple(self):
         from ptah import security
@@ -505,11 +497,9 @@ class TestOwnerLocalRoles(Base):
             security.get_local_roles('user', context=parent), ['system.Owner'])
 
 
-class TestCheckPermission(Base):
+class TestCheckPermission(PtahTestCase):
 
-    def setUp(self):
-        super(TestCheckPermission, self).setUp()
-        self._init_ptah()
+    _init_auth = True
 
     def test_checkpermission_allow(self):
         import ptah
@@ -550,15 +540,25 @@ class TestCheckPermission(Base):
 
         self.assertFalse(ptah.check_permission('View', content, throw=False))
 
-        ptah.authService.set_userid('test-user')
+        ptah.auth_service.set_userid('test-user')
         self.assertTrue(ptah.check_permission('View', content, throw=False))
 
     def test_checkpermission_user(self):
         import ptah
 
         content = Content(acl=[(Allow, 'test-user', 'View')])
+        self.assertFalse(ptah.check_permission('View', content, throw=False))
 
-        ptah.authService.set_userid('test-user')
+        ptah.auth_service.set_userid('test-user')
+        self.assertTrue(ptah.check_permission('View', content, throw=False))
+
+    def test_checkpermission_effective_user(self):
+        import ptah
+
+        content = Content(acl=[(Allow, 'test-user2', 'View')])
+
+        ptah.auth_service.set_userid('test-user')
+        ptah.auth_service.set_effective_userid('test-user2')
         self.assertTrue(ptah.check_permission('View', content, throw=False))
 
     def test_checkpermission_superuser(self):
@@ -568,7 +568,20 @@ class TestCheckPermission(Base):
         content = Content(
             acl=[(Deny, ptah.SUPERUSER_URI, security.ALL_PERMISSIONS)])
 
-        ptah.authService.set_userid(ptah.SUPERUSER_URI)
+        ptah.auth_service.set_userid(ptah.SUPERUSER_URI)
+        self.assertTrue(ptah.check_permission('View', content))
+        self.assertFalse(ptah.check_permission(ptah.NOT_ALLOWED, content))
+
+    def test_checkpermission_effective_superuser(self):
+        import ptah
+        from pyramid import security
+
+        content = Content(
+            acl=[(Deny, ptah.SUPERUSER_URI, security.ALL_PERMISSIONS)])
+
+        ptah.auth_service.set_userid('test-user')
+        ptah.auth_service.set_effective_userid(ptah.SUPERUSER_URI)
+
         self.assertTrue(ptah.check_permission('View', content))
         self.assertFalse(ptah.check_permission(ptah.NOT_ALLOWED, content))
 
@@ -579,8 +592,84 @@ class TestCheckPermission(Base):
             iface=ptah.ILocalRolesAware,
             acl=[(Allow, 'role:test', 'View')])
 
-        ptah.authService.set_userid('test-user')
+        ptah.auth_service.set_userid('test-user')
         self.assertFalse(ptah.check_permission('View', content, throw=False))
 
         content.__local_roles__['test-user'] = ['role:test']
         self.assertTrue(ptah.check_permission('View', content, throw=False))
+
+    def test_checkpermission_effective_local_roles(self):
+        import ptah
+
+        content = Content(
+            iface=ptah.ILocalRolesAware,
+            acl=[(Allow, 'role:test', 'View')])
+
+        ptah.auth_service.set_userid('test-user2')
+        self.assertFalse(ptah.check_permission('View', content, throw=False))
+
+        content.__local_roles__['test-user'] = ['role:test']
+        self.assertFalse(ptah.check_permission('View', content, throw=False))
+
+        ptah.auth_service.set_effective_userid('test-user')
+        self.assertTrue(ptah.check_permission('View', content, throw=False))
+
+
+class TestAauthorization(PtahTestCase):
+
+    _init_auth = True
+
+    def _make_one(self):
+        from ptah.security import PtahAuthorizationPolicy
+        return PtahAuthorizationPolicy()
+
+    def test_authz_allow_no_permissions(self):
+        authz = self._make_one()
+        content = Content(acl=[DENY_ALL])
+
+        self.assertFalse(
+            authz.permits(content, (ptah.Everyone.id,), 'View'))
+        self.assertTrue(
+            authz.permits(content, (ptah.Everyone.id,), NO_PERMISSION_REQUIRED))
+
+    def test_authz_deny_not_allowed(self):
+        authz = self._make_one()
+        content = Content(acl=[(Allow, ptah.Everyone.id, ALL_PERMISSIONS)])
+
+        self.assertTrue(authz.permits(
+            content, (ptah.Everyone.id,), 'View'))
+        self.assertFalse(authz.permits(
+            content, (ptah.Everyone.id,), ptah.NOT_ALLOWED))
+
+    def test_authz_effective_user(self):
+        authz = self._make_one()
+        content = Content(acl=[(Allow, 'test-user2', 'View')])
+
+        ptah.auth_service.set_effective_userid('test-user2')
+        self.assertFalse(
+            authz.permits(content, ('test-user',), 'View'))
+
+    def test_authz_superuser(self):
+        authz = self._make_one()
+        content = Content(acl=[(Allow, 'test-user2', 'View')])
+        self.assertTrue(authz.permits(content, (ptah.SUPERUSER_URI,), 'View'))
+
+    def test_authz_superuser_allow(self):
+        authz = self._make_one()
+        content = Content(
+            acl=[(Deny, ptah.SUPERUSER_URI, ptah.ALL_PERMISSIONS)])
+
+        self.assertTrue(
+            authz.permits(content, (ptah.SUPERUSER_URI,), 'View'))
+
+    def test_authz_effective_superuser(self):
+        authz = self._make_one()
+        content = Content(
+            acl=[(Deny, ptah.SUPERUSER_URI, ptah.ALL_PERMISSIONS)])
+
+        ptah.auth_service.set_effective_userid(ptah.SUPERUSER_URI)
+
+        self.assertTrue(
+            authz.permits(content, ('test-user',), 'View'))
+        self.assertFalse(
+            authz.permits(content, ('test-user',), ptah.NOT_ALLOWED))
